@@ -1,18 +1,18 @@
 from .orthanc_cloner import OrthancCloner, ClonerMode
 from .orthanc_folder_importer import *
+from .orthanc_forwarder import *
 from .orthanc_monitor import OrthancMonitor
 from .orthanc_test_db_populator import OrthancTestDbPopulator
 from .pacs_migrator import PacsMigrator
 from .orthanc_comparator import OrthancComparator
-from .scheduler import Scheduler
-from .old_files_deleter import OldFilesDeleter
 
 from .hl7Lib import *
+from .helpers import *
 
 # Set default logging handler to avoid "No handler found" warnings.
 import logging
 from logging import NullHandler
 
-logger = logging.getLogger('orthanc_tools')
+logger = logging.getLogger(__name__)
 logger.addHandler(NullHandler())
 
