@@ -4,10 +4,10 @@ import os
 from strenum import StrEnum
 
 from orthanc_api_client import OrthancApiClient, ResourceType, JobStatus, ResourceNotFound
-from .scheduler import Scheduler
+from .helpers.scheduler import Scheduler
 from .orthanc_monitor import OrthancMonitor, ChangeType
 
-logger = logging.getLogger('orthanc_tools')
+logger = logging.getLogger(__name__)
 
 
 class ClonerMode(StrEnum):
@@ -74,7 +74,8 @@ class OrthancCloner(OrthancMonitor):
                 api_client.peers.send(target_peer=self._destination_peer, resources_ids=instance_id)
 
         except ResourceNotFound as ex:
-            # some instances seems to be missing although their NewInstance change is still in DB.
+            # An instance may have been deleted (by a user, a script,...) between the moment we called the /changes route
+            # and the moment we try to handle it. So, the `get_file` will return a 404 http error.
             # In this case, simply log the error and do not retry in the OrthancMonitor (don't raise the Exception)
             if self._error_folder_path:
                 error_file_path = os.path.join(self._error_folder_path, f"{change_id:010d}.NewInstance.error.txt")
@@ -90,7 +91,7 @@ class OrthancCloner(OrthancMonitor):
     def handle_stable_study(self, change_id, study_id, api_client):
         try:
             if self._mode == ClonerMode.TRANSFER:
-                transfer_job = api_client.transfers.send(
+                transfer_job = api_client.transfers.send_async(
                     target_peer=self._destination_peer,
                     resources_ids=study_id,
                     resource_type=ResourceType.STUDY
