@@ -5,8 +5,8 @@ import os
 import logging
 
 from orthanc_api_client import OrthancApiClient, ChangeType
-from .scheduler import Scheduler
-logger = logging.getLogger('orthanc_tools')
+from .helpers.scheduler import Scheduler
+logger = logging.getLogger(__name__)
 
 
 class OrthancMonitor:
@@ -136,7 +136,7 @@ class OrthancMonitor:
             wt.start()
 
     def stop(self):
-        logger.info("Stopping Orthanc Monitor")
+        logger.debug("Stopping Orthanc Monitor")
 
         # first stop the monitoring thread so we don't produce events anymore
         self._is_running = False
@@ -154,6 +154,7 @@ class OrthancMonitor:
 
         last_sequence_id = self._start_at_sequence_id
         done = False
+        has_logged_connection_error = False  # to avoid repeating errors
 
         while self._is_running:
             if existing_changes_only and done:
@@ -161,7 +162,8 @@ class OrthancMonitor:
                 return
 
             done = False
-            while not done and self._is_running: # read as fast as you can while there are still events
+
+            while not done and self._is_running:  # read as fast as you can while there are still events
 
                 if self._scheduler:
                     self._scheduler.wait_right_time_to_run(logger=logger)
@@ -172,8 +174,13 @@ class OrthancMonitor:
                         since=last_sequence_id,
                         limit=100
                     )
+                    if has_logged_connection_error:
+                        has_logged_connection_error = False
+                        logger.warning("Connected to Orthanc again")
                 except Exception as ex:
-                    logger.warning("Could not reach Orthanc, retrying ...")
+                    if not has_logged_connection_error:
+                        logger.warning("Could not reach Orthanc, retrying silently...")
+                        has_logged_connection_error = True
                     break
 
                 # enqueue the events
